@@ -2,7 +2,7 @@
 //
 // Copyright (C) 2005  Dominick Samperi
 //
-// $Id: discount.cpp,v 1.5 2006/07/22 14:13:04 dsamperi Exp $
+// $Id: discount.cpp,v 1.6 2007/12/31 02:08:42 edd Exp $
 //
 // This program is part of the RQuantLib library for R (GNU S).
 // It is made available under the terms of the GNU General Public
@@ -25,12 +25,14 @@ RcppExport SEXP QL_DiscountCurve(SEXP params, SEXP tsQuotes,
 
 	// Parameter wrapper classes.
 	RcppParams rparam(params);
-	RcppNamedList tslist(tsQuotes);
+	RcppNumList tslist(tsQuotes);
 
 	int i;
 
-	Date todaysDate = rparam.getDateValue("tradeDate");
-	Date settlementDate = rparam.getDateValue("settleDate");
+	Date todaysDate( dateFromR(rparam.getDateValue("tradeDate") )); 
+	Date settlementDate( dateFromR(rparam.getDateValue("settleDate") )); 
+	// cout << "TradeDate: " << todaysDate << endl << "Settle: " << settlementDate << endl;
+
 	RQLContext::instance().settleDate = settlementDate;
 	Settings::instance().evaluationDate() = todaysDate;
 	string firstQuoteName = tslist.getName(0);
@@ -38,11 +40,13 @@ RcppExport SEXP QL_DiscountCurve(SEXP params, SEXP tsQuotes,
 	double dt = rparam.getDoubleValue("dt");
 	
 	string interpWhat, interpHow;
+	bool flatQuotes = true;
 	if(firstQuoteName.compare("flat") != 0) {
 
 	    // Get interpolation method (not needed for "flat" case)
 	    interpWhat = rparam.getStringValue("interpWhat");
 	    interpHow  = rparam.getStringValue("interpHow");
+	    flatQuotes = false;
 	}
 
         Calendar calendar = TARGET();
@@ -69,7 +73,7 @@ RcppExport SEXP QL_DiscountCurve(SEXP params, SEXP tsQuotes,
 	else {
 	    // Build curve based on a set of observed rates and/or prices.
 	    std::vector<boost::shared_ptr<RateHelper> > curveInput;
-	    for(i = 0; i < tslist.getLength(); i++) {
+	    for(i = 0; i < tslist.size(); i++) {
 		string name = tslist.getName(i);
 		double val = tslist.getValue(i);
 		boost::shared_ptr<RateHelper> rh = 
@@ -103,6 +107,7 @@ RcppExport SEXP QL_DiscountCurve(SEXP params, SEXP tsQuotes,
 	rs.add("discounts", disc, true);
 	rs.add("forwards", fwds, true);
 	rs.add("zerorates", zero, true);
+	rs.add("flatQuotes", flatQuotes);
 	rs.add("params", params, false);
 	rl = rs.getReturnList();
 
